from setuptools import setup

setup(name='binomial_gauss_distributions',
      version='0.1',
      description='Gaussian and Binomial Distributions',
      packages=['binomial_gauss_distributions'],
      zip_safe=False)
